---
title: <span class="badge object-type-scalar"></span> CFPFranc
---
# <span class="badge object-type-scalar"></span> CFPFranc

Currency: CFP franc (XPF)

## Definition

```python
# Currency: CFP franc (XPF)
CFPFranc: typing.Literal["currencyXPF"] = "currencyXPF"
```
